<?php

namespace Bixo\Activities\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Bixo\Activities\Http\Requests\MeetingRequest;
use Bixo\Activities\Interfaces\MeetingRepositoryInterface;
use Bixo\Activities\Models\Meeting;
use Bixo\Activities\Forms\Meeting as Form;

/**
 * APIController  class for meeting.
 */
class MeetingAPIController extends BaseController
{

    /**
     * Initialize meeting resource controller.
     *
     * @param type MeetingRepositoryInterface $meeting
     *
     * @return null
     */
    public function __construct(MeetingRepositoryInterface $meeting)
    {
        parent::__construct();
        $this->repository = $meeting;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bixo\Activities\Repositories\Criteria\MeetingResourceCriteria::class);
    }

    /**
     * Display a list of meeting.
     *
     * @return Response
     */
    public function index(MeetingRequest $request)
    {
        return $this->repository
            ->setPresenter(\Bixo\Activities\Repositories\Presenter\MeetingPresenter::class)
            ->paginate();
    }

    /**
     * Display meeting.
     *
     * @param Request $request
     * @param Model   $meeting
     *
     * @return Response
     */
    public function show(MeetingRequest $request, Meeting $meeting)
    {
        return $meeting->setPresenter(\Bixo\Activities\Repositories\Presenter\MeetingListPresenter::class);
        ;
    }

    /**
     * Create new meeting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(MeetingRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('activities::meeting.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('activities/meeting/' . $meeting->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('activities/meeting');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the meeting.
     *
     * @param Request $request
     * @param Model   $meeting
     *
     * @return Response
     */
    public function update(MeetingRequest $request, Meeting $meeting)
    {
        try {
            $data = $request->all();

            $meeting->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('activities::meeting.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('activities/meeting/' . $meeting->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('activities/meeting/' . $meeting->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the meeting.
     *
     * @param Model   $meeting
     *
     * @return Response
     */
    public function destroy(MeetingRequest $request, Meeting $meeting)
    {
        try {
            $meeting->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('activities::meeting.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('activities/meeting/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('activities/meeting/' . $meeting->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
