<?php

namespace Bixo\Activities\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Activities\Models\Task;

class TaskPolicy
{

    /**
     * Determine if the given user can view the task.
     *
     * @param UserPolicy $user
     * @param Task $task
     *
     * @return bool
     */
    public function view(UserPolicy $user, Task $task)
    {
        if ($user->canDo('activities.task.view') && $user->isAdmin()) {
            return true;
        }

        return $task->user_id == user_id() && $task->user_type == user_type();
    }

    /**
     * Determine if the given user can create a task.
     *
     * @param UserPolicy $user
     * @param Task $task
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('activities.task.create');
    }

    /**
     * Determine if the given user can update the given task.
     *
     * @param UserPolicy $user
     * @param Task $task
     *
     * @return bool
     */
    public function update(UserPolicy $user, Task $task)
    {
        if ($user->canDo('activities.task.edit') && $user->isAdmin()) {
            return true;
        }

        return $task->user_id == user_id() && $task->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given task.
     *
     * @param UserPolicy $user
     * @param Task $task
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Task $task)
    {
        return $task->user_id == user_id() && $task->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given task.
     *
     * @param UserPolicy $user
     * @param Task $task
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Task $task)
    {
        if ($user->canDo('activities.task.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given task.
     *
     * @param UserPolicy $user
     * @param Task $task
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Task $task)
    {
        if ($user->canDo('activities.task.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
