<?php

namespace Bixo\Activities\Providers;

use Illuminate\Support\ServiceProvider;

class ActivitiesServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'activities');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'activities');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerActivities();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerActivities()
    {
        $this->app->bind('activities', function($app) {
            return new Activities($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Activities', 'Lavalite\Activities\Facades\Activities');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('bixo.activities', function ($app) {
            return $this->app->make('Bixo\Activities\Activities');
        });

        // Bind Call to repository
        $this->app->bind(
            'Bixo\Activities\Interfaces\CallRepositoryInterface',
            \Bixo\Activities\Repositories\Eloquent\CallRepository::class
        );
        // Bind Meeting to repository
        $this->app->bind(
            'Bixo\Activities\Interfaces\MeetingRepositoryInterface',
            \Bixo\Activities\Repositories\Eloquent\MeetingRepository::class
        );
        // Bind Task to repository
        $this->app->bind(
            'Bixo\Activities\Interfaces\TaskRepositoryInterface',
            \Bixo\Activities\Repositories\Eloquent\TaskRepository::class
        );
        // Bind Attendee to repository
        $this->app->bind(
            'Bixo\Activities\Interfaces\AttendeeRepositoryInterface',
            \Bixo\Activities\Repositories\Eloquent\AttendeeRepository::class
        );
        // Bind Calendar to repository
        $this->app->bind(
            'Bixo\Activities\Interfaces\CalendarRepositoryInterface',
            \Bixo\Activities\Repositories\Eloquent\CalendarRepository::class
        );

        $this->app->register(\Bixo\Activities\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Bixo\Activities\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and activities's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'bixo.activities'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeActivities::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bixo.activities'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('bixo/activities.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/activities')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/activities')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
