<?php

namespace Bixo\Activities\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Bixo\Activities\Models\Activities;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Bixo\Activities\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/activities/call/*')) {
            Route::bind('call', function ($call) {
                $callrepo = $this->app->make('Bixo\Activities\Interfaces\CallRepositoryInterface');
                return $callrepo->findorNew($call);
            });
        }

        if (Request::is('*/activities/meeting/*')) {
            Route::bind('meeting', function ($meeting) {
                $meetingrepo = $this->app->make('Bixo\Activities\Interfaces\MeetingRepositoryInterface');
                return $meetingrepo->findorNew($meeting);
            });
        }

        if (Request::is('*/activities/task/*')) {
            Route::bind('task', function ($task) {
                $taskrepo = $this->app->make('Bixo\Activities\Interfaces\TaskRepositoryInterface');
                return $taskrepo->findorNew($task);
            });
        }

        if (Request::is('*/activities/attendee/*')) {
            Route::bind('attendee', function ($attendee) {
                $attendeerepo = $this->app->make('Bixo\Activities\Interfaces\AttendeeRepositoryInterface');
                return $attendeerepo->findorNew($attendee);
            });
        }

        if (Request::is('*/activities/calendar/*')) {
            Route::bind('calendar', function ($calendar) {
                $calendarrepo = $this->app->make('Bixo\Activities\Interfaces\CalendarRepositoryInterface');
                return $calendarrepo->findorNew($calendar);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
